import json from '@rollup/plugin-json';
import { nodeResolve } from '@rollup/plugin-node-resolve';
import replace from '@rollup/plugin-replace';
import commonjs from 'rollup-plugin-commonjs';
import scss from 'rollup-plugin-scss';
import typescript from 'rollup-plugin-typescript2';
import vue from 'rollup-plugin-vue';
import pkg from './package.json';

const packagePrefix = 'ss-';

const buildName = (name) => {
  const libraryName = name.replace('@', '').replace('/', '-');
  const pathName = libraryName.substring(packagePrefix.length);
  const camelCaseName = libraryName.replace(/-(\w)/g, (all, letter) => letter.toUpperCase());
  return { libraryName, pathName, camelCaseName };
};

const res = buildName(pkg.name);
const libraryName = res.libraryName;

const external = [
  'vue',
  'lodash-es',
  'ant-design-vue',
  '@element-plus/icons-vue',
  'element-plus',
  '@kunlun/dependencies',
  '@kunlun/vue-ui-antd',
  '@kunlun/vue-ui-el'
];

const tsconfigOverride = {
  compilerOptions: {
    outDir: 'dist',
    declaration: true,
    declarationDir: 'dist/types'
  },
  include: ['index.ts', 'src/**/*.ts'],
  exclude: ['tests/**/*.ts', 'tests/**/*.tsx']
};

const plugins = [
  replace({
    'process.env.NODE_ENV': JSON.stringify('development'),
    preventAssignment: true
  }),
  nodeResolve(),

  typescript({ useTsconfigDeclarationDir: true, tsconfigOverride }),

  vue(),

  scss({
    fileName: `${libraryName}.scss`,
    output: `dist/${libraryName}.scss`,
    sourceMap: false,
    outputStyle: 'compressed'
  }),

  json(),
  commonjs()
];

export default {
  input: `index.ts`,
  output: [
    {
      file: `dist/${libraryName}.esm.js`,
      format: 'esm',
      sourcemap: false
    }
  ],
  onwarn(warning) {
    if (warning.code === 'THIS_IS_UNDEFINED' || /Circular/.test(warning.message)) {
      return;
    }

    console.error(warning.message);
  },
  external,
  plugins
};
