import { ActionWidget, ServerActionWidget, SPI, Widget, DefaultTabsWidget } from '@kunlun/dependencies';
import NextStepVue from './NextStep.vue';

@SPI.ClassFactory(
  ActionWidget.Token({
    model: 'resource.ResourceCountry',
    name: 'create'
  })
)
export class NextStepAction extends ServerActionWidget {
  public initialize(props) {
    super.initialize(props);
    this.setComponent(NextStepVue);
    return this;
  }

  @Widget.BehaviorSubContext(Symbol('$$MULTI_TAB_HANDER_SUB'))
  private multiTabSubHander;

  private multiTabHander;

  private nextCb;

  @Widget.Reactive()
  private index = 0;

  @Widget.Reactive()
  private isNotLast = true;

  @Widget.Method()
  public async clickAction() {
    this.nextStep('next');
  }

  @Widget.Method()
  public async clickBeforeAction() {
    this.nextStep('before');
  }

  @Widget.Method()
  public async clickSave() {
    this.handleSave();
  }

  public handleSave() {
    super.clickAction();
  }

  public nextStep(step) {
    const handler = Widget.select(this.multiTabHander)!.getOperator();
    const handlerKeys = handler!.getChildren().map((hand) => {
      return hand.getHandle();
    });
    const activeKey = (handler as DefaultTabsWidget)!.getActiveKey();
    const index = handlerKeys.findIndex((v) => v === activeKey);
    const stepCount = step === 'before' ? index - 1 : index + 1;
    this.index = stepCount;
    this.isNotLast = stepCount !== handlerKeys.length;
    if (stepCount >= handlerKeys.length || stepCount < 0) {
      return;
    }
    this.nextCb(handlerKeys[stepCount]);
  }

  mounted() {
    super.mounted();
    this.multiTabSubHander.subscribe((value) => {
      if (value) {
        this.multiTabHander = value.handleKey;
        this.nextCb = value.change;
      }
    });
  }
}

// @SPI.ClassFactory(
//   ActionWidget.Token({
//     model: 'resource.ResourceCity',
//     name: 'create'
//   })
// )
// export class CustomServer1Action extends NextStepAction {}
